// 视频变声相关的全局变量
let processedVideoUrl = null;

// 选择视频文件后的处理
document.getElementById('videoFile').addEventListener('change', function(e) {
    const file = e.target.files[0];
    if (file) {
        // 显示原始视频
        const sourceVideo = document.getElementById('sourceVideo');
        sourceVideo.src = URL.createObjectURL(file);
        sourceVideo.load();
    }
});

// 开始视频变声处理
async function startVideoVoiceChange() {
    const videoFile = document.getElementById('videoFile').files[0];
    const character = document.getElementById('videoCharacter2').value;

    if (!videoFile) {
        showError('请先选择视频文件');
        return;
    }

    const button = document.getElementById('startVideoProcess');
    const errorDiv = document.getElementById('errorMessage2');

    try {
        // 更新按钮状态
        button.disabled = true;
        button.textContent = '处理中...';
        errorDiv.style.display = 'block';
        errorDiv.textContent = '正在处理视频，请稍候...';

        // 创建FormData对象
        const formData = new FormData();
        formData.append('video', videoFile);
        formData.append('character', character);
        formData.append('speed', document.getElementById('speed').value);
        formData.append('volume', document.getElementById('volume').value);
        formData.append('fragment_interval', document.getElementById('fragment_interval').value);
        formData.append('seed', getSeedValue());

        // 发送请求
        const response = await fetch('/video_change_voice', {
            method: 'POST',
            body: formData
        });

        const result = await response.json();

        if (result.success) {
            // 更新处理后的视频显示
            const processedVideo = document.getElementById('processedVideo');
            processedVideo.src = result.video_path;
            processedVideo.load();

            // 保存处理后的视频URL用于下载
            processedVideoUrl = result.video_path;

            // 显示下载按钮
            document.getElementById('downloadProcessedVideo').style.display = 'block';

            // 更新状态提示
            errorDiv.textContent = '视频处理完成';
            errorDiv.style.color = '#00bb00';
        } else {
            // 显示错误信息
            errorDiv.textContent = result.message;
            errorDiv.style.color = '#ff4444';
        }
    } catch (error) {
        // 显示错误信息
        errorDiv.textContent = error.message;
        errorDiv.style.color = '#ff4444';
    } finally {
        // 恢复按钮状态
        button.disabled = false;
        button.textContent = '开始视频变声';
    }
}

// 下载处理后的视频
function downloadProcessedVideo() {
    if (processedVideoUrl) {
        const link = document.createElement('a');
        link.href = processedVideoUrl;
        link.download = 'processed_video.mp4';
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
    }
}

// 辅助函数：获取seed值
function getSeedValue() {
    const keepRandom = document.getElementById('keepRandom').checked;
    const seedInput = document.getElementById('seed');
    if (keepRandom) {
        seedValue = getRandomSeed();
        seedInput.value = seedValue;
    }
    return seedInput.value
}

// 辅助函数：显示错误信息
function showError(message) {
    const errorDiv = document.getElementById('errorMessage');
    errorDiv.style.display = 'block';
    errorDiv.textContent = message;
    errorDiv.style.color = '#ff4444';
}