// 创建音频文件列表项
function createAudioFileListItem(fileName, file) {
    const div = document.createElement('div');
    div.className = 'file-item';
    div.innerHTML = `
        <input type="checkbox" class="file-checkbox" checked>
        <div class="file-name">${fileName}</div>
        <div class="file-status">等待处理</div>
        <div class="file-audio"></div>
        <button class="down-btn" style="display: none">下载音频</button>
        <button class="delete-btn" onclick="removeAudioFile(this)">删除</button>
    `;
    // 将File对象存储在DOM元素上
    div.dataset.file = JSON.stringify({name: fileName});
    div._file = file; // 存储实际的File对象
    return div;
}

// 监听音频文件上传
document.getElementById('audioFiles').addEventListener('change', function(e) {
    const files = Array.from(e.target.files);
    const audioFileList = document.getElementById('audioFileList');
    
    for(let file of files) {
        const fileItem = createAudioFileListItem(file.name, file);
        audioFileList.appendChild(fileItem);
    }
});

// 删除音频文件
function removeAudioFile(btn) {
    btn.parentElement.remove();
}

// 处理音频文件
document.getElementById('startVoiceChange').addEventListener('click', async function() {
    const fileItems = Array.from(document.querySelectorAll('.file-item'));
    const selectedFiles = fileItems.filter(item => 
        item.querySelector('.file-checkbox').checked
    );

    if(selectedFiles.length === 0) {
        alert('请选择要处理的文件');
        return;
    }

    for(let item of selectedFiles) {
        const statusElement = item.querySelector('.file-status');
        const audioContainer = item.querySelector('.file-audio');
        const downContainer = item.querySelector('.down-btn');
        const file = item._file; // 获取存储的File对象

        statusElement.textContent = '处理中...';

        try {
            const formData = new FormData();
            formData.append('file', file);
            formData.append('character', document.getElementById('voiceCharacter').value);
            formData.append('speed', document.getElementById('speed').value);
            formData.append('volume', document.getElementById('volume').value);
            formData.append('fragment_interval', document.getElementById('fragment_interval').value);
            formData.append('seed', getSeedValue());

            const response = await fetch('/asr', {
                method: 'POST',
                body: formData
            });

            const data = await response.json();
            if(data.success) {
                statusElement.textContent = '已完成';
                audioContainer.innerHTML = `
                    <audio controls src="${data.audio_url}"></audio>
                `;
                audioContainer.style.display = 'block';

                downContainer.style.display = 'block';
                downContainer.addEventListener('click', () => {
                    const link = document.createElement('a');
                    link.href = data.audio_url;
                    link.download = JSON.parse(item.dataset.file).name.replace(/\.[^/.]+$/, '') + '_changed.mp3';
                    link.click();
                });
            } else {
                statusElement.textContent = '处理失败，请确认asr是否运行或是否音频过大';
            }
        } catch(error) {
            statusElement.textContent = '处理失败';
            console.error(error);
        }
    }
});