// 页面加载完成后执行
document.addEventListener('DOMContentLoaded', function() {
    loadApiList();

    // 每30秒刷新一次API列表
    // setInterval(loadApiList, 3000);
});

function loadApiList() {
    fetch('/get_apis')
        .then(response => response.json())
        .then(data => {
            if(data.status === 'success') {
                // 更新角色选择弹窗
                const characterList = document.querySelector('.character-list');
                characterList.innerHTML = data.apis.map(name =>
                    `<div class="character-item" onclick="selectCharacter('${name}')">${name}</div>`
                ).join('');

                // 更新批量处理下拉框
                const batchSelect = document.getElementById('defaultCharacterBatch');
                batchSelect.innerHTML = data.apis.map(name =>
                    `<option value="${name}">${name}</option>`
                ).join('');

                // 更新变声模式下拉框
                const voiceSelect = document.getElementById('voiceCharacter');
                voiceSelect.innerHTML = data.apis.map(name =>
                    `<option value="${name}">${name}</option>`
                ).join('');

                // 更新变声模式下拉框
                const videoCharacter2 = document.getElementById('videoCharacter2');
                videoCharacter2.innerHTML = data.apis.map(name =>
                    `<option value="${name}">${name}</option>`
                ).join('');

                // 设置默认角色
                // if(data.default_api) {
                //     document.getElementById('defaultCharacterBtnVal').value = data.default_api;
                //     document.getElementById('defaultCharacterBtn').querySelector('span').textContent = data.default_api;
                // }
            }
        })
        .catch(error => {
            console.error('Failed to load API list:', error);
        });
}


let progressInterval;

function updateBatchProgress() {
    const total = document.querySelectorAll('.file-item').length;
    // 修改这行，使用更准确的选择器
    const completed = document.querySelectorAll('.file-status').length;
    const completedCount = Array.from(document.querySelectorAll('.file-status')).filter(el => el.textContent === '已完成').length;
    const progress = (completedCount / total) * 100;
    document.querySelector('#batchProgress progress').value = progress;
}

function updateProgress() {
    const progressBar = document.querySelector('.progress progress');
    let value = 85; // 起始值
    let direction = 1; // 1表示增加，-1表示减少

    progressBar.value = value;
    progressInterval = setInterval(() => {
        // 在85-95之间来回跳动
        if (value >= 95) {
            direction = -1;
        } else if (value <= 85) {
            direction = 1;
        }
        value += direction * 2;
        progressBar.value = value;
    }, 200); // 每200ms跳动一次
}

function stopProgress() {
    if (progressInterval) {
        clearInterval(progressInterval);
        progressInterval = null;
        const progressBar = document.querySelector('.progress progress');
        progressBar.value = 100; // 完成时直接填满
    }
}

function downloadAudio() {
    const audio = document.getElementById('audio');
    const text = document.getElementById('text').value;
    const fileName = text.slice(0, 20).replace(/[^\w\s]/gi, '') + '.wav';

    const link = document.createElement('a');
    link.href = audio.src;
    link.download = fileName;
    link.click();
}

let currentSeed = -1;

function getRandomSeed() {
    rand_val = Math.floor(Math.random() * (Math.pow(2, 32) - 100000) + 100000);
    return rand_val
}

function randomizeSeed() {
    document.getElementById('seed').value = -1;
    // currentSeed = getRandomSeed();
    // document.getElementById('seed').value = currentSeed;
}

document.getElementById('volume').addEventListener('input', function(e) {
    document.getElementById('volumeValue').textContent = e.target.value;
});

document.getElementById('speed').addEventListener('input', function(e) {
    document.getElementById('speedValue').textContent = e.target.value;
});

function closeModal(modalId) {
    document.getElementById(modalId).style.display = 'none';
}

// 点击弹窗外部关闭弹窗
window.onclick = function(event) {
    if (event.target.classList.contains('modal')) {
        event.target.style.display = 'none';
    }
}